package com.pyvio.openapi.sdk.client;

public enum Endpoint {
    AccessTokenGet("/oauth/api/v1/token", Constants.HttpMethod.POST, false),

    // User
    UserCreate("/user/api/v2/user/register", Constants.HttpMethod.POST, true),
    UserGet("/user/api/v1/unit/query", Constants.HttpMethod.GET, true),
    UserUpdate("/user/api/v2/user/edit", Constants.HttpMethod.POST, true),

    // Balance
    BalanceGet("/finance/api/v1/balance", Constants.HttpMethod.GET, true),
    BalanceHistory("/finance/api/v1/balance/history", Constants.HttpMethod.GET, true),
    BalanceList("/finance/api/v1/balance/list", Constants.HttpMethod.GET, true),

    // Shop
    ShopCreate("/user/api/v1/shop/create", Constants.HttpMethod.POST, true),
    ShopGet("/user/api/v1/shop/query", Constants.HttpMethod.GET, true),
    ShopList("/user/api/v1/shop/list", Constants.HttpMethod.GET, true),
    ShopUpdate("/user/api/v1/shop/edit", Constants.HttpMethod.POST, true),

    // GlobalAccount
    GlobalAccountOpen("/user/api/v1/va/apply", Constants.HttpMethod.POST, true),
    GlobalAccountGet("/user/api/v1/va/get", Constants.HttpMethod.GET, true),
    GlobalAccountList("/user/api/v1/va/list", Constants.HttpMethod.GET, true),
    GlobalAccountGetWelcomeLetterGet("/user/api/v1/va/welcomeLetter", Constants.HttpMethod.GET, true),

    // Collection
    CollectionList("/inbound/api/v1/collect/list", Constants.HttpMethod.GET, true),
    CollectionGet("/inbound/api/v1/collect/detail", Constants.HttpMethod.GET, true),
    CollectionAttachmentSubmit("/inbound/api/v1/collect/attachment/submit", Constants.HttpMethod.POST, true),

    // Payee
    PayeeCreate("/user/api/v1/payee/create", Constants.HttpMethod.POST, true),
    PayeeUpdate("/user/api/v1/payee/edit", Constants.HttpMethod.POST, true),
    PayeeGet("/user/api/v1/payee/get", Constants.HttpMethod.GET, true),
    PayeeList("/user/api/v1/payee/list", Constants.HttpMethod.GET, true),
    PayeeDelete("/user/api/v1/payee/delete", Constants.HttpMethod.GET, true),

    // CNY Repatriation
    RepatriationOrderUpload("/order-center/api/v1/order/upload", Constants.HttpMethod.POST, true),
    RepatriationOrderImport("/order-center/api/v1/order/import", Constants.HttpMethod.POST, true),
    ContractOrderCreate("/order-center/api/v1/contract/order/add", Constants.HttpMethod.POST, true),
    ContractOrderUpdate("/order-center/api/v1/contract/order/edit", Constants.HttpMethod.POST, true),
    ContractOrderGet("/order-center/api/v1/contract/order/get", Constants.HttpMethod.POST, true),
    ContractOrderDelete("/order-center/api/v1/contract/order/delete", Constants.HttpMethod.POST, true),
    ContractOrderLogistic("/order-center/api/v1/contract/order/supplementLogistics", Constants.HttpMethod.POST, true),
    AvailableCNYWithdrawAmount("/order-center/api/v1/order/availableCredit", Constants.HttpMethod.GET, true),

    // Fx
    QueryFxRate("/fx/api/v1/rate", Constants.HttpMethod.POST, true),
    FxOrderCreate("/fx/api/v1/order/create", Constants.HttpMethod.POST, true),
    FxOrderQuery("/fx/api/v1/order/query", Constants.HttpMethod.GET, true),
    FxOrderList("/fx/api/v1/order/list", Constants.HttpMethod.GET, true),

    // Payment
    QueryPaymentFx("/outbound/api/v1/fx", Constants.HttpMethod.POST, true),
    PaymentCreate("/outbound/api/v1/payment/create", Constants.HttpMethod.POST, true),
    PaymentGet("/outbound/api/v1/payment/get", Constants.HttpMethod.GET, true),
    PaymentList("/outbound/api/v1/payment/list", Constants.HttpMethod.GET, true),
    CertificateGet("/outbound/api/v1/payment/download/certificate", Constants.HttpMethod.GET, true),

    // Transfer
    TransferCreate("/outbound/api/v1/transfer/create", Constants.HttpMethod.POST, true),
    TransferGet("/outbound/api/v1/transfer/get", Constants.HttpMethod.GET, true),
    TransferList("/outbound/api/v1/transfer/list", Constants.HttpMethod.GET, true),

    // Issuing
    CardholderCreate("/issuing/api/v2/cardHolder/apply", Constants.HttpMethod.POST, true),
    CardholderGet("/issuing/api/v2/cardHolder/detail", Constants.HttpMethod.GET, true),
    CardCreate("/issuing/api/v2/card/apply", Constants.HttpMethod.POST, true),
    CardStatusGet("/issuing/api/v2/card/queryApplyCardStatus", Constants.HttpMethod.GET, true),
    CardDetailGet("/issuing/api/v2/card/detail", Constants.HttpMethod.GET, true),
    CardBalanceGet("/issuing/api/v2/card/balance", Constants.HttpMethod.GET, true),
    CardRecharge("/issuing/api/v2/card/recharge", Constants.HttpMethod.POST, true),
    CardWithdraw("/issuing/api/v2/card/withdraw", Constants.HttpMethod.POST, true),
    CardCancel("/issuing/api/v2/card/cancel", Constants.HttpMethod.POST, true),
    AuthTransactionsGet("/issuing/api/v2/transactions/authorization", Constants.HttpMethod.GET, true),
    SettlementGet("/issuing/api/v2/transactions/settlement", Constants.HttpMethod.GET, true),
    CardTransactionsGet("/issuing/api/v2/transactions/queryCardTransactions", Constants.HttpMethod.GET, true),

    // File
    FileUpload("/file/api/v1/upload", Constants.HttpMethod.POST, true),

    // Report
    ReportList("/report/api/v1/fundBillReport/list", Constants.HttpMethod.GET, true),
    ReportDownload("/report/api/v1/fundBillReport/download", Constants.HttpMethod.GET, true),

    UnitGet("/user/api/v1/unit/get", Constants.HttpMethod.GET, true),
    ;

    Endpoint(String url, String method, boolean authorization) {
        this.url = url;
        this.method = method;
        this.authorization = authorization;
    }

    private final String method;
    private final String url;
    private final boolean authorization;

    public String getMethod() {
        return method;
    }

    public String getUrl() {
        return url;
    }

    public boolean isAuthorization() {
        return authorization;
    }

    @Override
    public String toString() {
        return url;
    }
}
