import com.alibaba.fastjson.JSONObject;
import com.pyvio.openapi.sdk.client.Endpoint;
import com.pyvio.openapi.sdk.client.PyvioClient;
import com.pyvio.openapi.sdk.entity.info.BankAccountInfo;
import com.pyvio.openapi.sdk.entity.info.PayeeInfo;
import com.pyvio.openapi.sdk.entity.payee.*;
import com.pyvio.openapi.sdk.enums.PayeeEnum;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.Map;

public class PayeeTest extends BaseTest {

    private static final Logger log = LoggerFactory.getLogger(BaseTest.class);

    @Test
    public void testPayeeVNDCreate() {
        log.info("------------testPayeeCreate---------------");
        PyvioClient pyvioClient = getClient(Endpoint.PayeeCreate);

        PayeeInfo payeeInfo = new PayeeInfo();
        payeeInfo.setPayee_country("VN");
//        payeeInfo.setCompany_name("company name");
//        payeeInfo.setPhone("111111");

        BankAccountInfo bankAccountInfo = new BankAccountInfo();
        bankAccountInfo.setAccount_name("VU TUNG DUONG");
        bankAccountInfo.setBank_name("MBBANK - Military Commercial Joint Stock Bank");
        bankAccountInfo.setAccount_no("0397775854");
//        bankAccountInfo.setSwift_code("CITIHK33");
//        bankAccountInfo.setBank_code("023");
//        bankAccountInfo.setBranch_code("1234");
        bankAccountInfo.setAccount_country("VN");
        bankAccountInfo.setRouting_type1(PayeeEnum.RoutingType.Local.getCode());

        PayeeCreateRequest request = new PayeeCreateRequest();
        request.setPartner_payee_id("pe" + System.currentTimeMillis());
        request.setPayee_type(PayeeEnum.PayeeType.SupplierBankAccount.getCode());
        request.setPayment_method(PayeeEnum.PaymentMethod.Local.getCode());
        request.setHolder_type(PayeeEnum.HolderType.Personal.getCode());
        request.setCurrency("VND");
//        request.setReference("783aded6aa0848c39f37e50e2054b659");
        request.setPayee_info(payeeInfo);
        request.setBank_account_info(bankAccountInfo);

//        Map<String, String> header = new HashMap<>();
//        header.put("X-Unit-Id", "UT1676140408448164849");
//
//        request.setHeader(header);


        PayeeDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testPayeeCreate---------------");
    }

    @Test
    public void testPayeeCreate() {
        log.info("------------testPayeeCreate---------------");
        PyvioClient pyvioClient = getClient(Endpoint.PayeeCreate);

        PayeeInfo payeeInfo = new PayeeInfo();
        payeeInfo.setPayee_country("NG");
        payeeInfo.setFirst_name("first");
        payeeInfo.setLast_name("last");
//        payeeInfo.setCompany_name("company name");
        payeeInfo.setPhone("111111");

        BankAccountInfo bankAccountInfo = new BankAccountInfo();
        bankAccountInfo.setAccount_name("TEST");
        bankAccountInfo.setBank_name("eNaira(e-Naira)");
        bankAccountInfo.setAccount_no("0000000000");
//        bankAccountInfo.setSwift_code("CITIHK33");
        bankAccountInfo.setBank_code("033");
//        bankAccountInfo.setBranch_code("1234");
        bankAccountInfo.setAccount_country("NG");
        bankAccountInfo.setRouting_type1(PayeeEnum.RoutingType.Local.getCode());

        PayeeCreateRequest request = new PayeeCreateRequest();
        request.setPartner_payee_id("pe" + System.currentTimeMillis());
        request.setPayee_type(PayeeEnum.PayeeType.SupplierBankAccount.getCode());
        request.setPayment_method(PayeeEnum.PaymentMethod.Local.getCode());
        request.setHolder_type(PayeeEnum.HolderType.Company.getCode());
        request.setCurrency("NGN");
        request.setContact_documents("783aded6aa0848c39f37e50e2054b659");
        request.setPayee_info(payeeInfo);
        request.setBank_account_info(bankAccountInfo);

//        Map<String, String> header = new HashMap<>();
//        header.put("X-Unit-Id", "UT1676140408448164849");
//
//        request.setHeader(header);


        PayeeDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testPayeeCreate---------------");
    }

    @Test
    public void testPayeeUpdate() {
        log.info("------------testPayeeCreate---------------");
        PyvioClient pyvioClient = getClient(Endpoint.PayeeUpdate);

        PayeeInfo payeeInfo = new PayeeInfo();
        payeeInfo.setFirst_name("first name");
        payeeInfo.setLast_name("last name");
        payeeInfo.setEmail("persion@test.com");
        payeeInfo.setPhone("533696800");
        payeeInfo.setPayee_country("US");
        payeeInfo.setProvince("California");
        payeeInfo.setCity("Los Angeles");
        payeeInfo.setPost_code("90001");
        payeeInfo.setStreet_address("123 Main Street");

        BankAccountInfo bankAccountInfo = new BankAccountInfo();
        bankAccountInfo.setAccount_no("6877028002");
        bankAccountInfo.setAccount_country("US");
        bankAccountInfo.setBank_name("CITI BANK");
        bankAccountInfo.setBank_address("11 PENNS WAY");
        bankAccountInfo.setAccount_name("account name");
        bankAccountInfo.setBank_code("023");
        bankAccountInfo.setBranch_address("5554 California Ave");
        bankAccountInfo.setBranch_code("12345");
        bankAccountInfo.setBranch_name("Oswell");
        bankAccountInfo.setSwift_code("CITIUS33");
        bankAccountInfo.setRouting_type1(PayeeEnum.RoutingType.Fedwire.getCode());
        bankAccountInfo.setRouting_value1("321171184");
        bankAccountInfo.setProvince("California");
        bankAccountInfo.setCity("Bakersfield");

        PayeeUpdateRequest request = new PayeeUpdateRequest();
        request.setPayee_id("ba1780805888901994037");
//        request.setPartner_payee_id("pe"+System.currentTimeMillis());
        request.setPayee_type(PayeeEnum.PayeeType.SupplierBankAccount.getCode());
        request.setPayment_method(PayeeEnum.PaymentMethod.Local.getCode());
        request.setHolder_type(PayeeEnum.HolderType.Personal.getCode());
        request.setCurrency("USD");
        request.setContact_documents("783aded6aa0848c39f37e50e2054b659");
        request.setPayee_info(payeeInfo);
        request.setBank_account_info(bankAccountInfo);

        PayeeDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testPayeeCreate---------------");
    }

    @Test
    public void testGetPayee() {
        log.info("------------PayeeGetResponse---------------");
        PyvioClient pyvioClient = getClient(Endpoint.PayeeGet);

        PayeeGetRequest request = new PayeeGetRequest();
        request.setPartner_payee_id("pe1713766177927");

        PayeeDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------PayeeGetResponse---------------");
    }

    @Test
    public void testDeletePayee() {
        log.info("------------testDeletePayee---------------");
        PyvioClient pyvioClient = getClient(Endpoint.PayeeDelete);

        PayeeDeleteRequest request = new PayeeDeleteRequest();
        request.setPayee_id("ba1780805888901994037");

        PayeeDeleteResponse response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testDeletePayee---------------");
    }

}
