import com.alibaba.fastjson.JSON;
import com.pyvio.openapi.sdk.client.Endpoint;
import com.pyvio.openapi.sdk.client.PyvioClient;
import com.pyvio.openapi.sdk.entity.fx.QueryFxRateRequest;
import com.pyvio.openapi.sdk.entity.fx.QueryFxRateResponse;
import com.pyvio.openapi.sdk.entity.info.PayerInfo;
import com.pyvio.openapi.sdk.entity.payment.*;
import com.pyvio.openapi.sdk.enums.CalOriginEnum;
import com.pyvio.openapi.sdk.enums.PaymentEnum;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

public class PaymentTest extends BaseTest{
    private static final Logger log = LoggerFactory.getLogger(BaseTest.class);

    @Test
    public void testQueryPaymentFxRequest() {
        log.info("------------testQueryPaymentFxRequest---------------");
        PyvioClient client = getClient(Endpoint.QueryPaymentFx);
        QueryPaymentFxRequest request = new QueryPaymentFxRequest();
        request.setOrigin_currency("USD");
        request.setTarget_currency("EUR");
        QueryPaymentFxResponse execute = client.execute(request);
        System.out.println(JSON.toJSONString(execute));
        log.info("------------testQueryPaymentFxRequest---------------");
    }

    @Test
    public void testPaymentCreateRequest() {
        log.info("------------testPaymentCreateRequest---------------");
        PyvioClient client = getClient(Endpoint.PaymentCreate);
        PaymentCreateRequest request = new PaymentCreateRequest();
        request.setPartner_order_id("pay"+System.currentTimeMillis());
        request.setOrder_type(PaymentEnum.OrderType.Payout.getCode());
        request.setCal_origin(CalOriginEnum.Type.TARGET2ORIGIN.getCode());
        request.setAmount(BigDecimal.valueOf(100));
        request.setOrigin_currency("USD");
        request.setTarget_currency("USD");
        request.setPayee_id("ba1780805888901994059");

        PayerInfo payerInfo = new PayerInfo();
        payerInfo.setPayer_type("individual");
        payerInfo.setPayer_city("city");
        payerInfo.setPayer_postcode("code");
        payerInfo.setPayer_country("US");
        payerInfo.setPayer_date_of_birth("2000-01-01");
        payerInfo.setPayer_state("state");
        payerInfo.setPayer_address("address");
        payerInfo.setPayer_first_name("first");
        payerInfo.setPayer_last_name("last");
        payerInfo.setPayer_id_number("id1num");

        request.setPayer(payerInfo);

        PaymentDTO execute = client.execute(request);
        System.out.println(JSON.toJSONString(execute));
        log.info("------------testPaymentCreateRequest---------------");
    }

    @Test
    public void testPaymentGetRequest() {
        log.info("------------testPaymentCreateRequest---------------");
        PyvioClient client = getClient(Endpoint.PaymentGet);
        PaymentGetRequest request = new PaymentGetRequest();
        request.setOrder_id("P2404231780444478159070303");
        PaymentDTO execute = client.execute(request);
        System.out.println(JSON.toJSONString(execute));
        log.info("------------testPaymentCreateRequest---------------");
    }

    @Test
    public void testPaymentListRequest() {
        log.info("------------testPaymentListRequest---------------");
        PyvioClient client = getClient(Endpoint.PaymentList);
        PaymentListRequest request = new PaymentListRequest();
        request.setPage_no(1);
        request.setPage_size(100);

        PaymentListResponse execute = (PaymentListResponse)client.execute(request);
        System.out.println(JSON.toJSONString(execute));
        log.info("------------testPaymentListRequest---------------");
    }

    @Test
    public void testCertificateGetRequest() {
        log.info("------------testCertificateGetRequest---------------");
        PyvioClient client = getClient(Endpoint.CertificateGet);
        CertificateGetRequest request = new CertificateGetRequest();
        request.setOrder_id("P2404231780444478159070303");

        CertificateGetResponse execute = client.execute(request);
        System.out.println(JSON.toJSONString(execute));
        log.info("------------testCertificateGetRequest---------------");
    }
}
