

import com.alibaba.fastjson.JSONObject;
import com.pyvio.openapi.sdk.client.Endpoint;
import com.pyvio.openapi.sdk.client.PyvioClient;
import com.pyvio.openapi.sdk.entity.info.ContractTradeGoodsInfo;
import com.pyvio.openapi.sdk.entity.info.GoodsOrderInfo;
import com.pyvio.openapi.sdk.entity.repatriation.*;
import com.pyvio.openapi.sdk.enums.RepatriationEnum;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * @author hyt
 * @version $Id: RepatriationOrderTest.java, v 0.1 2022年11月10日 10:03 AM
 */
public class RepatriationOrderTest extends BaseTest {

    private static final Logger log = LoggerFactory.getLogger(BaseTest.class);

    @Test
    public void testOrderUpload() {
        log.info("------------testOrderUpload---------------");
        PyvioClient pyvioClient = getClient(Endpoint.RepatriationOrderUpload);

        RepatriationOrderUploadRequest request = new RepatriationOrderUploadRequest();
        request.setFile_id("8947399c21bb40dcb77feae35945540e");
        request.setOrder_type(RepatriationEnum.OrderType.Ads.getCode());

        RepatriationOrderUploadResponse response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testOrderUpload---------------");
    }

    @Test
    public void testOrderImport() {
        log.info("------------testOrderImport---------------");
        PyvioClient pyvioClient = getClient(Endpoint.RepatriationOrderImport);

        GoodsOrderInfo goods1 = new GoodsOrderInfo();
        goods1.setShop_link("http://myshop.link");
        goods1.setCategory("Women is clothing and accessories");
        goods1.setOrder_amount(BigDecimal.valueOf(700));
        goods1.setUnit_price(BigDecimal.valueOf(70));
        goods1.setItem_quantity(10L);
        goods1.setTracking_number("HHJ099988181");
        goods1.setCurrency("USD");
        goods1.setOrder_product("clothes");
        goods1.setOrder_type(RepatriationEnum.OrderType.Goods.getCode());
        goods1.setCarrier("EMS");
        goods1.setOrder_time("2024-06-28 16:36:06");
        goods1.setShipping_country("US");
        goods1.setOrder_id("20240128163302506");

        List<GoodsOrderInfo> goodsOrderInfoList = new ArrayList<>();
        goodsOrderInfoList.add(goods1);

        RepatriationOrderImportRequest request = new RepatriationOrderImportRequest();
        request.setOrder_type(RepatriationEnum.OrderType.Goods.getCode());
        request.setGoods_order_list(goodsOrderInfoList);

        RepatriationOrderImportResponse response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testOrderImport---------------");
    }


    @Test
    public void testContractOrderCreateRequest(){
        log.info("------------testContractOrderCreateRequest---------------");
        PyvioClient pyvioClient = getClient(Endpoint.ContractOrderCreate);

        ContractTradeGoodsInfo tradeGoodsInfo = new ContractTradeGoodsInfo();
        tradeGoodsInfo.setPlatform("platform");
        tradeGoodsInfo.setOrder_product("product");
        tradeGoodsInfo.setCategory("category");
        tradeGoodsInfo.setPayer_type("NEW");
        tradeGoodsInfo.setShop_link("http://yourshop.link");
        tradeGoodsInfo.setItem_quantity(8);
        tradeGoodsInfo.setTrade_country("US");
        tradeGoodsInfo.setCarrier("carrier");
        tradeGoodsInfo.setTracking_number("number1112");
        tradeGoodsInfo.setLogistics_file("e17a8f49c75c4d939ab9df006dd686de");

        ContractOrderCreateRequest request = new ContractOrderCreateRequest();
        request.setOrder_id("order_id1234561123");
        request.setCurrency("USD");
        request.setOrder_type(RepatriationEnum.ContractOrderType.B2BGoods.getCode());
        request.setOrder_amount(BigDecimal.valueOf(1888.12));
        request.setOrder_time(1726044272000L);
        request.setPayer_name("payer name");
        request.setPayer_bank_name("bank name");
        request.setPayer_bank_card("bank card");
        request.setFile_info("e17a8f49c75c4d939ab9df006dd686de");
        request.setTrade_goods(tradeGoodsInfo);

        ContractOrderDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testContractOrderCreateRequest---------------");
    }

    @Test
    public void testContractOrderUpdateRequest(){
        log.info("------------testContractOrderUpdateRequest---------------");
        PyvioClient pyvioClient = getClient(Endpoint.ContractOrderUpdate);

        ContractTradeGoodsInfo tradeGoodsInfo = new ContractTradeGoodsInfo();
        tradeGoodsInfo.setPlatform("platform");
        tradeGoodsInfo.setOrder_product("product");
        tradeGoodsInfo.setCategory("category");
        tradeGoodsInfo.setPayer_type("NEW");
        tradeGoodsInfo.setShop_link("http://yourshop.link");
        tradeGoodsInfo.setItem_quantity(8);
        tradeGoodsInfo.setTrade_country("US");
        tradeGoodsInfo.setCarrier("carrier");
        tradeGoodsInfo.setTracking_number("number111");
        tradeGoodsInfo.setLogistics_file("123");

        ContractOrderUpdateRequest request = new ContractOrderUpdateRequest();
        request.setBatch_no("B1780187283448519943");
        request.setOrder_id("order_id1234511");
        request.setCurrency("USD");
        request.setOrder_type(RepatriationEnum.ContractOrderType.B2BGoods.getCode());
        request.setOrder_amount(BigDecimal.valueOf(888.12));
        request.setOrder_time(1726044272000L);
        request.setPayer_name("payer name");
        request.setPayer_bank_name("bank name");
        request.setPayer_bank_card("bank card");
        request.setFile_info("e17a8f49c75c4d939ab9df006dd686de");
        request.setTrade_goods(tradeGoodsInfo);

        ContractOrderDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testContractOrderUpdateRequest---------------");
    }

    @Test
    public void testContractOrderGetRequest() {
        log.info("------------testContractOrderGetRequest---------------");
        PyvioClient pyvioClient = getClient(Endpoint.ContractOrderGet);

        ContractOrderGetRequest request = new ContractOrderGetRequest();
        request.setBatch_no("B1828310827823906313");

        ContractOrderGetResponse response = pyvioClient.execute(request);

        System.out.println(JSONObject.toJSONString(response));

        log.info("------------testContractOrderGetRequest---------------");
    }

    @Test
    public void testContractOrderDeleteRequest() {
        log.info("------------testContractOrderDeleteRequest---------------");
        PyvioClient pyvioClient = getClient(Endpoint.ContractOrderDelete);

        ContractOrderDeleteRequest request = new ContractOrderDeleteRequest();
        request.setBatch_no("B1780187283448519943");

        ContractOrderDeleteResponse response = pyvioClient.execute(request);

        System.out.println(JSONObject.toJSONString(response));

        log.info("------------testContractOrderDeleteRequest---------------");
    }

    @Test
    public void testContractOrderLogisticRequest() {
        log.info("------------testContractOrderLogisticRequest---------------");
        PyvioClient pyvioClient = getClient(Endpoint.ContractOrderLogistic);
        ContractOrderLogisticRequest request = new ContractOrderLogisticRequest();
        request.setTracking_number("tracking number");
        request.setCarrier("carrier");
        request.setBatch_no("B1780187283448519942");
        request.setLogistics_file("e17a8f49c75c4d939ab9df006dd686de");
        ContractOrderLogisticResponse response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testContractOrderLogisticRequest---------------");
    }

    @Test
    public void testAvailableCNYWithdrawRequest() {
        log.info("------------testAvailableCNYWithdrawRequest---------------");
        PyvioClient pyvioClient = getClient(Endpoint.AvailableCNYWithdrawAmount);
        AvailableCNYWithdrawRequest request = new AvailableCNYWithdrawRequest();
        AvailableCNYWithdrawResponse response =(AvailableCNYWithdrawResponse) pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testAvailableCNYWithdrawRequest---------------");
    }
}
