import com.alibaba.fastjson.JSONObject;
import com.pyvio.openapi.sdk.client.Endpoint;
import com.pyvio.openapi.sdk.client.PyvioClient;
import com.pyvio.openapi.sdk.entity.user.UserUpdateRequest;
import com.pyvio.openapi.sdk.enums.FileEnum;
import com.pyvio.openapi.sdk.entity.info.AddressInfo;
import com.pyvio.openapi.sdk.entity.info.AttachmentInfo;
import com.pyvio.openapi.sdk.entity.info.CompanyInfo;
import com.pyvio.openapi.sdk.entity.info.PersonInfo;
import com.pyvio.openapi.sdk.entity.user.UserCreateRequest;
import com.pyvio.openapi.sdk.enums.UserEnum;
import com.pyvio.openapi.sdk.entity.user.UserGetRequest;
import com.pyvio.openapi.sdk.entity.user.UserDTO;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;

public class UserTest extends BaseTest {

    private static final Logger log = LoggerFactory.getLogger(BaseTest.class);

    // 创建用户
    @Test
    public void testUserCreate() {
        log.info("------------testUserCreate---------------");
        UserCreateRequest request = new UserCreateRequest();

        // 如果需要用已通过的 clientId 进行创建多 Unit,必填
//         request.setClient_id("CT1777652043454820287");

        request.setPartner_user_id("u"+System.currentTimeMillis());
        request.setEmail("zzh@xx.com");
//        request.setPhone("18899990002");
        request.setMerchant_type(UserEnum.MerchantType.B2C.getCode());
        request.setKyc_type(UserEnum.KycType.ForeignEnterprise.getCode());

        // 企业行业类别
        List<String> industry = new ArrayList<>();
        industry.add("Electronics");
        industry.add("Computers");
        request.setIndustry(industry);

        // 企业注册信息
        CompanyInfo companyInfo = new CompanyInfo();
        companyInfo.setCompany_name("company name");
        companyInfo.setCompany_type(UserEnum.CompanyType.LimitedCompany.getCode());
        companyInfo.setIdentify_no("companyIdNo12345a121");
        companyInfo.setCompany_name_en("company name en");
        companyInfo.setEstablish_date("2024-01-01");
        companyInfo.setCommencement_date("2024-01-01");
        companyInfo.setValid_period("2026-01-01");
        companyInfo.setListed("0");
        companyInfo.setState_owned_enterprised("0");
        companyInfo.setForeign_owned_enterprised("0");

        // 企业证件文件
        AttachmentInfo attachment1 = new AttachmentInfo();
        attachment1.setFil_type(FileEnum.SSC.getCode());
        attachment1.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment2 = new AttachmentInfo();
        attachment2.setFil_type(FileEnum.BAP.getCode());
        attachment2.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment3 = new AttachmentInfo();
        attachment3.setFil_type(FileEnum.CI.getCode());
        attachment3.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment4 = new AttachmentInfo();
        attachment4.setFil_type(FileEnum.AOA.getCode());
        attachment4.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment5 = new AttachmentInfo();
        attachment5.setFil_type(FileEnum.Other.getCode());
        attachment5.setFile_id("162723251118409faa22380048db6702");

        List<AttachmentInfo> companyAttachmentList = new ArrayList<>();
        companyAttachmentList.add(attachment1);
        companyAttachmentList.add(attachment2);
        companyAttachmentList.add(attachment3);
        companyAttachmentList.add(attachment4);
        companyAttachmentList.add(attachment5);
        companyInfo.setAttachments(companyAttachmentList);

        // 企业注册地址
        AddressInfo registerAddress = new AddressInfo();
        registerAddress.setCountry("US");
        registerAddress.setState("California");
        registerAddress.setCity("Los Angeles");
        registerAddress.setPostcode("90001");
        registerAddress.setLine1("456 Main Street");
        companyInfo.setRegister_address(registerAddress);

        // 企业经营地址
        AddressInfo operationAddress = new AddressInfo();
        operationAddress.setCountry("US");
        operationAddress.setState("California");
        operationAddress.setCity("Los Angeles");
        operationAddress.setPostcode("90001");
        operationAddress.setLine1("456 Main Street");
        companyInfo.setOperation_address(operationAddress);

        // 法人信息
        PersonInfo legalInfo = new PersonInfo();
        legalInfo.setName("legal name");
        legalInfo.setName_en("legal name en");
        legalInfo.setId_number("02120010");
        legalInfo.setDate_of_birth("1999-01-01");
        legalInfo.setIssue_date("2014-01-01");
        legalInfo.setExpiration_date("2024-01-01");

        // 法人证件文件
        List<AttachmentInfo> legalAttachmentList = new ArrayList<>();
        AttachmentInfo legalAttachment = new AttachmentInfo();
        legalAttachment.setFil_type(FileEnum.PP.getCode());
        legalAttachment.setFile_id("162723251118409faa22380048db6702");
        legalAttachmentList.add(legalAttachment);
        legalInfo.setAttachments(legalAttachmentList);

        // 法人证件地址
        AddressInfo legalResidentialAddress = new AddressInfo();
        legalResidentialAddress.setCountry("US");
        legalResidentialAddress.setState("California");
        legalResidentialAddress.setCity("Los Angeles");
        legalResidentialAddress.setPostcode("90001");
        legalResidentialAddress.setLine1("456 Main Street");
        legalInfo.setResidential_address(legalResidentialAddress);

        companyInfo.setLegal_info(legalInfo);

        // UBO1 信息
        PersonInfo ubo1 = new PersonInfo();
        ubo1.setName("legal name");
        ubo1.setName_en("legal name en");
        ubo1.setId_number("02120010");
        ubo1.setDate_of_birth("1999-01-01");
        ubo1.setIssue_date("2014-01-01");
        ubo1.setExpiration_date("2024-01-01");

        // UBO1 证件文件
        List<AttachmentInfo> ubo1AttachmentList = new ArrayList<>();
        AttachmentInfo ubo1Attachment = new AttachmentInfo();
        ubo1Attachment.setFil_type(FileEnum.PP.getCode());
        ubo1Attachment.setFile_id("162723251118409faa22380048db6702");
        ubo1AttachmentList.add(ubo1Attachment);
        ubo1.setAttachments(ubo1AttachmentList);

        // UBO1 证件地址
        AddressInfo ubo1ResidentialAddress = new AddressInfo();
        ubo1ResidentialAddress.setCountry("US");
        ubo1ResidentialAddress.setState("California");
        ubo1ResidentialAddress.setCity("Los Angeles");
        ubo1ResidentialAddress.setPostcode("90001");
        ubo1ResidentialAddress.setLine1("456 Main Street");
        ubo1.setResidential_address(ubo1ResidentialAddress);
        List<PersonInfo> uboList = new ArrayList<>();
        uboList.add(ubo1);

        companyInfo.setUbo_list(uboList);

        request.setCompany_info(companyInfo);

        PyvioClient pyvioClient = getClient(Endpoint.UserCreate);

        UserDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));

        log.info("------------testUserCreate---------------");
    }
    // 创建用户
    @Test
    public void testUserVNCreate() {
        log.info("------------testUserVNCreate---------------");
        UserCreateRequest request = new UserCreateRequest();
        request.setPartner_user_id("u"+System.currentTimeMillis());
        request.setMerchant_type(UserEnum.MerchantType.B2C.getCode());
        request.setKyc_type(UserEnum.KycType.VietnamForeignIndividual.getCode());

        // 企业行业类别
        List<String> industry = new ArrayList<>();
        industry.add("Electronics");
        industry.add("Computers");
        request.setIndustry(industry);

        // 个人信息
        PersonInfo individualInfo = new PersonInfo();
        individualInfo.setName("legal name");
        individualInfo.setName_en("legal name en");
        individualInfo.setId_number("021200101");
        individualInfo.setDate_of_birth("1999-01-01");
        individualInfo.setIssue_date("2014-01-01");
        individualInfo.setExpiration_date("2024-01-01");

        AddressInfo residential_address = new AddressInfo();
        residential_address.setCountry("US");
        residential_address.setState("California");
        residential_address.setCity("Los Angeles");
        residential_address.setPostcode("90001");
        residential_address.setLine1("456 Main Street");
        individualInfo.setResidential_address(residential_address);

        // 证件文件
        List<AttachmentInfo> legalAttachmentList = new ArrayList<>();
        AttachmentInfo legalAttachment = new AttachmentInfo();
        legalAttachment.setFil_type(FileEnum.PP.getCode());
        legalAttachment.setFile_id("39becc91d6e04238940da431b7e188c5");
        AttachmentInfo legalAttachment2 = new AttachmentInfo();
        legalAttachment2.setFil_type(FileEnum.POA.getCode());
        legalAttachment2.setFile_id("39becc91d6e04238940da431b7e188c5");
        legalAttachmentList.add(legalAttachment);
        legalAttachmentList.add(legalAttachment2);
        individualInfo.setAttachments(legalAttachmentList);


        request.setIndividual_info(individualInfo);

        PyvioClient pyvioClient = getClient(Endpoint.UserCreate);

        UserDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));

        log.info("------------testUserCreate---------------");
    }

    // 编辑用户
    @Test
    public void testUserUpdate() {
        log.info("------------testUserUpdate---------------");
        UserUpdateRequest request = new UserUpdateRequest();

        request.setPartner_user_id("u"+System.currentTimeMillis());
        request.setUnit_id("UT12345");
        request.setExtra_document("162723251118409faa22380048db6702");
//        request.setEmail("test123qwe1@163.com");
//        request.setPhone("18899990002");
        request.setMerchant_type(UserEnum.MerchantType.B2C.getCode());
        request.setKyc_type(UserEnum.KycType.ForeignEnterprise.getCode());

        // 企业行业类别
        List<String> industry = new ArrayList<>();
        industry.add("Electronics");
        industry.add("Computers");
        request.setIndustry(industry);

        // 企业注册信息
        CompanyInfo companyInfo = new CompanyInfo();
        companyInfo.setCompany_name("company name");
        companyInfo.setCompany_type(UserEnum.CompanyType.LimitedCompany.getCode());
        companyInfo.setIdentify_no("companyIdNo12345a12");
        companyInfo.setCompany_name_en("company name en");
        companyInfo.setEstablish_date("2024-01-01");
        companyInfo.setCommencement_date("2024-01-01");
        companyInfo.setValid_period("2026-01-01");
        companyInfo.setListed("0");
        companyInfo.setState_owned_enterprised("0");
        companyInfo.setForeign_owned_enterprised("0");

        // 企业证件文件
        AttachmentInfo attachment1 = new AttachmentInfo();
        attachment1.setFil_type(FileEnum.SSC.getCode());
        attachment1.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment2 = new AttachmentInfo();
        attachment2.setFil_type(FileEnum.BAP.getCode());
        attachment2.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment3 = new AttachmentInfo();
        attachment3.setFil_type(FileEnum.CI.getCode());
        attachment3.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment4 = new AttachmentInfo();
        attachment4.setFil_type(FileEnum.AOA.getCode());
        attachment4.setFile_id("162723251118409faa22380048db6702");
        AttachmentInfo attachment5 = new AttachmentInfo();
        attachment5.setFil_type(FileEnum.Other.getCode());
        attachment5.setFile_id("162723251118409faa22380048db6702");

        List<AttachmentInfo> companyAttachmentList = new ArrayList<>();
        companyAttachmentList.add(attachment1);
        companyAttachmentList.add(attachment2);
        companyAttachmentList.add(attachment3);
        companyAttachmentList.add(attachment4);
        companyAttachmentList.add(attachment5);
        companyInfo.setAttachments(companyAttachmentList);

        // 企业注册地址
        AddressInfo registerAddress = new AddressInfo();
        registerAddress.setCountry("US");
        registerAddress.setState("California");
        registerAddress.setCity("Los Angeles");
        registerAddress.setPostcode("90001");
        registerAddress.setLine1("456 Main Street");
        companyInfo.setRegister_address(registerAddress);

        // 企业经营地址
        AddressInfo operationAddress = new AddressInfo();
        operationAddress.setCountry("US");
        operationAddress.setState("California");
        operationAddress.setCity("Los Angeles");
        operationAddress.setPostcode("90001");
        operationAddress.setLine1("456 Main Street");
        companyInfo.setOperation_address(operationAddress);

        // 法人信息
        PersonInfo legalInfo = new PersonInfo();
        legalInfo.setName("legal name");
        legalInfo.setName_en("legal name en");
        legalInfo.setId_number("02120010");
        legalInfo.setDate_of_birth("1999-01-01");
        legalInfo.setIssue_date("2014-01-01");
        legalInfo.setExpiration_date("2024-01-01");

        // 法人证件文件
        List<AttachmentInfo> legalAttachmentList = new ArrayList<>();
        AttachmentInfo legalAttachment = new AttachmentInfo();
        legalAttachment.setFil_type(FileEnum.PP.getCode());
        legalAttachment.setFile_id("162723251118409faa22380048db6702");
        legalAttachmentList.add(legalAttachment);
        legalInfo.setAttachments(legalAttachmentList);

        // 法人证件地址
        AddressInfo legalResidentialAddress = new AddressInfo();
        legalResidentialAddress.setCountry("US");
        legalResidentialAddress.setState("California");
        legalResidentialAddress.setCity("Los Angeles");
        legalResidentialAddress.setPostcode("90001");
        legalResidentialAddress.setLine1("456 Main Street");
        legalInfo.setResidential_address(legalResidentialAddress);

        companyInfo.setLegal_info(legalInfo);

        // UBO1 信息
        PersonInfo ubo1 = new PersonInfo();
        ubo1.setName("legal name");
        ubo1.setName_en("legal name en");
        ubo1.setId_number("02120010");
        ubo1.setDate_of_birth("1999-01-01");
        ubo1.setIssue_date("2014-01-01");
        ubo1.setExpiration_date("2024-01-01");

        // UBO1 证件文件
        List<AttachmentInfo> ubo1AttachmentList = new ArrayList<>();
        AttachmentInfo ubo1Attachment = new AttachmentInfo();
        ubo1Attachment.setFil_type(FileEnum.PP.getCode());
        ubo1Attachment.setFile_id("162723251118409faa22380048db6702");
        ubo1AttachmentList.add(ubo1Attachment);
        ubo1.setAttachments(ubo1AttachmentList);

        // UBO1 证件地址
        AddressInfo ubo1ResidentialAddress = new AddressInfo();
        ubo1ResidentialAddress.setCountry("US");
        ubo1ResidentialAddress.setState("California");
        ubo1ResidentialAddress.setCity("Los Angeles");
        ubo1ResidentialAddress.setPostcode("90001");
        ubo1ResidentialAddress.setLine1("456 Main Street");
        ubo1.setResidential_address(ubo1ResidentialAddress);
        List<PersonInfo> uboList = new ArrayList<>();
        uboList.add(ubo1);

        companyInfo.setUbo_list(uboList);

        request.setCompany_info(companyInfo);

        PyvioClient pyvioClient = getClient(Endpoint.UserUpdate);

        UserDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));

        log.info("------------testUserUpdate---------------");
    }

    @Test
    public void testUserGet() {
        log.info("------------testUserGet---------------");
        UserGetRequest request = new UserGetRequest();
//        request.setUnit_id("UT1776897702954117945");

        request.setPartner_user_id("pv1234567");

        PyvioClient pyvioClient = getClient(Endpoint.UserGet);
        UserDTO response = pyvioClient.execute(request);
        System.out.println(JSONObject.toJSONString(response));
        log.info("------------testUserGet---------------");
    }

}
